<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('Redux_Framework_sample_config')) {

    class Redux_Framework_sample_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (  true == Redux_Helpers::isTheme(__FILE__) ) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 3);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field	set with compiler=>true is changed.

         * */
        function compiler_action($options, $css, $changed_values) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r($changed_values); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )

            /*
              // Demo of how to use the dynamic CSS and write your own static CSS file
              $filename = dirname(__FILE__) . '/style' . '.css';
              global $wp_filesystem;
              if( empty( $wp_filesystem ) ) {
                require_once( ABSPATH .'/wp-admin/includes/file.php' );
              WP_Filesystem();
              }

              if( $wp_filesystem ) {
                $wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                );
              }
             */
        }

        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', 'redux-framework-demo'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns        = array();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array();

                    while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[]  = array('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'redux-framework-demo'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'redux-framework-demo'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'redux-framework-demo'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'redux-framework-demo') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'redux-framework-demo'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $sampleHTML = '';
            if (file_exists(dirname(__FILE__) . '/info-html.html')) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH . '/wp-admin/includes/file.php');
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
            }

            // ACTUAL DECLARATION OF SECTIONS


            /**********************************
            ********* General Setting ***********
            ***********************************/

            $this->sections[] = array(
                'title'         => __('General Setting', 'Home Setting'),
                'icon'          => 'el-icon-wrench',
                'icon_class'    => 'el-icon-small',
                'fields'        => array(

                    array(
                        'id'        => 'preload-en',
                        'type'      => 'switch',
                        'title'     => __('Preload', 'themeum'),
                        'subtitle'  => __('Enable or disable preload', 'themeum'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'home-latest-event-en',
                        'type'      => 'switch',
                        'title'     => __('Home Latest Event', 'themeum'),
                        'subtitle'  => __('Enable or disable', 'themeum'),
                        'default'   => true,
                    ),                    

                    array(
                        'id'        => 'home-countdown-en',
                        'type'      => 'switch',
                        'title'     => __('Home Countdown', 'themeum'),
                        'subtitle'  => __('Enable or disable', 'themeum'),
                        'default'   => true,
                        'required'  => array('home-latest-event-en', "=", 1),
                    ),

                    array(
                        'id'        => 'social-share',
                        'type'      => 'select',
                        'title'     => __('Select Social Share Style', 'themeum'),
                        'subtitle'  => __('Select social share style', 'themeum'),  
                        'options'   => array(
                            '1'     => 'Share Button with Count',
                            '2'     => 'Share Button without Count'
                        ),
                        'default'   => '1',
                    ),

                    array(
                        'id'        => 'map-api-key',
                        'type'      => 'text',
                        'title'     => __('Google Map API Key', 'themeum'),
                        'subtitle' => __('Put here Google Map API Key', 'themeum'),
                        'default'   => 'AIzaSyDh1eLs0rpNzEL9GpVMxJDu5ggCZqEtcbI',
                    ),

                    array(
                        'id'        => 'before-head',
                        'type'      => 'ace_editor',
                        'title'     => __('Text Before &#60;&#47;head&#62;', 'themeum'),
                        'subtitle'  => __('Use costom code before &#60;&#47;Head&#62', 'themeum'),                                            
                    ),  

                    array(
                        'id'        => 'before-footer',
                        'type'      => 'ace_editor',
                        'title'     => __('Before &#60;&#47;footer&#62;', 'themeum'),
                        'subtitle'  => __('Use costom code before &#60;&#47;footer&#62', 'themeum'),                                            
                    ),





                )
            );


            /**********************************
            ********* Header Setting ***********
            ***********************************/

            $this->sections[] = array(
                'title'         => __('Header', 'Home Setting'),
                'icon'          => 'el-icon-bookmark',
                'icon_class'    => 'el-icon-large',
                'fields'        => array(

                    array(
                        'id'        => 'header-fixed',
                        'type'      => 'switch',
                        'title'     => __('Sticky Header', 'themeum'),
                        'subtitle'  => __('Enable or disable sicky Header', 'themeum'),
                        'default'   => false,
                    ),

                    array(
                        'id'        => 'woo-cart-en',
                        'type'      => 'switch',
                        'title'     => __('Woo Cart', 'themeum'),
                        'subtitle'  => __('Enable or disable', 'themeum'),
                        'default'   => true,
                    ),  

                    array(
                        'id'        => 'header-margin-top',
                        'type'      => 'text',
                        'title'     => __('Header Top Margin', 'themeum'),
                        'subtitle'  => __('Enter custom header top marign ex. 10px', 'themeum'),
                        'default'   => '0',

                    ),  

                    array(
                        'id'        => 'header-margin-bottom',
                        'type'      => 'text',
                        'title'     => __('Header Bottom Margin', 'themeum'),
                        'subtitle'  => __('Enter custom header bottom margin ex. 10px', 'themeum'),
                        'default'   => '30px',

                    ),                                                           

                )
            );


            /**********************************
            ********* Menu Setting ************
            ***********************************/
            $this->sections[] = array(
                'title'     => esc_html__('Menu Settings', 'Home Setting'),
                'icon'      => 'el-align-justify',
                'icon_class' => 'el-icon-large',
                'fields'    => array(

                    array(
                        'id'        => 'header-bg',
                        'type'      => 'color_rgba',
                        'title'     => __('Menu Background Color', 'themeum'),
                        'subtitle'  => __('Set menu background color', 'themeum'),
                        'default'   => array('color' => '#000000', 'alpha' => '.8'),
                        'output'    => array('.navbar-default'),
                        'mode'      => 'background',
                        'validate'  => 'colorrgba',
                    ),

                    array(
                        'id'        => 'menu-font-color',
                        'type'      => 'color',
                        'title'     => __('Menu Text Color', 'themeum'),
                        'subtitle'  => __('Pick a text color for the Menu (default: #fff).', 'themeum'),
                        'default'   => '#fff',
                        'validate'  => 'color',
                    ),

                    array(
                        'id'        => 'menu-text-hover-color',
                        'type'      => 'color',
                        'title'     => __('Menu Text Hover Color', 'themeum'),
                        'subtitle'  => __('Pick a Text hover color (default: #ec5538).', 'themeum'),
                        'default'   => '#ec5538',
                        'validate'  => 'color',
                    ),

                    array(
                        'id'        => 'menu-padding-top',
                        'type'      => 'text',
                        'title'     => __('Menu padding Top ex. 30', 'themeum'),
                        'subtitle' => __('Enter custom Menu padding Top', 'themeum'),
                        'default'   => '',
                    ),

                    array(
                        'id'        => 'menu-padding-bottom',
                        'type'      => 'text',
                        'title'     => __('Menu padding Bottom ex. 30', 'themeum'),
                        'subtitle' => __('Enter custom menu padding Bottom', 'themeum'),
                        'default'   => '',
                    ),

                    # sub menu
                    array(
                        'id'        => 'submenu-bg',
                        'type'      => 'color',
                        'title'     => __('Sub Menu Background Color', 'themeum'),
                        'subtitle'  => __('Pick a background color for the Subenu (default: #ec5538).', 'themeum'),
                        'default'   => '#ec5538',
                        'validate'  => 'color',
                    ),
                    array(
                        'id'        => 'submenu-text-color',
                        'type'      => 'color',
                        'title'     => __('Sub Menu Text Color', 'themeum'),
                        'subtitle'  => __('Pick a Text color for the Submenu (default: #fff).', 'themeum'),
                        'default'   => '#fff',
                        'validate'  => 'color',
                        'transparent'   =>false,
                    ),

                    array(
                        'id'        => 'submenu-text-hover-color',
                        'type'      => 'color',
                        'title'     => __('Sub Menu Text Hover Color', 'themeum'),
                        'subtitle'  => __('Pick a Text Hover color for the Submenu (default: #fff).', 'themeum'),
                        'default'   => '#fff',
                        'validate'  => 'color',
                        'transparent'   =>false,
                    ),
                                                                                                                                                                        
                )
            );


            /**********************************
            **** Sub Header Color  *****
            ***********************************/
            
            $this->sections[] = array(
                'title'     => __('Sub Header', 'themeum'),
                'icon'      => 'sub-header-icon',
                'icon_class' => 'el-icon-compass',
                'fields'    => array(

                    array(
                        'id'        => 'subtitle-title-color',
                        'type'      => 'color',
                        'title'     => __('Sub Title Color', 'themeum'),
                        'subtitle'  => __('Pick a subtitle color (default: #fff).', 'themeum'),
                        'default'   => '#fff',
                        'validate'  => 'color',
                        'transparent'   =>false,
                    ), 

                    array(
                        'id'        => 'subtitle-padding-top',
                        'type'      => 'text',
                        'title'     => __('Subtitle padding Top ex. 30', 'themeum'),
                        'subtitle' => __('Enter custom Subtitle padding Top', 'themeum'),
                        'default'   => '',
                    ),

                    array(
                        'id'        => 'subtitle-padding-bottom',
                        'type'      => 'text',
                        'title'     => __('Subtitle padding Bottom ex. 30', 'themeum'),
                        'subtitle' => __('Enter custom Subtitle padding Bottom', 'themeum'),
                        'default'   => '',
                    ),

                ));



            /**********************************
            ********* Logo & Favicon ***********
            ***********************************/

            $this->sections[] = array(
                'title'         => __('Logo & favicon', 'themeum'),
                'icon'          => 'el-icon-photo',
                'icon_class'    => 'el-icon-large',
                'fields'        => array(

                    array( 
                        'id'        => 'favicon', 
                        'type'      => 'media',
                        'desc'      => __('Upload favicon image', 'themeum'),
                        'title'     => 'Favicon',
                        'subtitle'  => __('Upload favicon image', 'themeum'),
                        'default'   => array( 'url' => get_template_directory_uri() .'/images/favicon.png' ), 
                    ),                 

                    array(
                        'id'        =>'logo',
                        'url'       => false,
                        'type'      => 'media', 
                        'title'     => __('Logo', 'themeum'),
                        'default'   => array( 'url' => get_template_directory_uri() .'/images/logo.png' ),
                        'subtitle'  => __('Upload your custom site logo.', 'themeum'),
                    ),

                    array(
                        'id'        => 'logo-width',
                        'type'      => 'text',
                        'title'     => esc_html__('Logo Width', 'themeum'),
                        'subtitle' => esc_html__('Custom Logo width...', 'themeum'),
                        'default'   => '',
                    ), 

                    array(
                        'id'        => 'logo-height',
                        'type'      => 'text',
                        'title'     => esc_html__('Logo Height', 'themeum'),
                        'subtitle' => esc_html__('Custom Logo height...', 'themeum'),
                        'default'   => '',
                    ),

                    array(
                        'id'        => 'logo-text-en',
                        'type'      => 'switch',
                        'title'     => __('Text Type Logo', 'themeum'),
                        'subtitle'  => __('Enable or disable text type logo', 'themeum'),
                        'default'   => false,
                    ),

                    array(
                        'id'        => 'logo-text',
                        'type'      => 'text',
                        'title'     => __('Logo Text', 'themeum'),
                        'subtitle'  => __('Use your Custom logo text ex. vocal', 'themeum'),
                        'default'   => 'Vocal',
                        'required'  => array('logo-text-en', "=", 0),

                    ),

                )
            );

            $this->sections[] = array(
                'title'         => __('Site Background', 'themeum'),
                'icon'          => 'el-icon-brush',
                'icon_class'    => 'el-icon-large',
                'fields'        => array(

                    array(
                        'id'        => 'background-type',
                        'type'      => 'select',
                        'title'     => __('Select Background Type', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for gallery single page', 'themeum'),
                        'options'   => array(
                            '1'     => 'Background Slider',
                            '2'     => 'Background Video',
                            '3'     => 'Background Image Only',
                            '4'     => 'Background Color Only'
                        ),
                        'default'  => '3'
                    ),

                    array(
                        'id'        => 'slider-bg',
                        'type'      => 'gallery',
                        'title'     => __('Background Slider Images' , 'themeum'),
                        'subtitle'  => __('Upload slider images for background ', 'themeum')
                    ),

                    array(
                        'id'        =>'image-bg',
                        'url'       => false,
                        'type'      => 'media', 
                        'title'     => __('Background Images Only', 'themeum'),
                        'default'   => array( 'url' => get_template_directory_uri() .'/images/bg.png' ),
                        'subtitle'  => __('Upload images for background image only type', 'themeum'),
                    ),

                    array(
                        'id'        => 'site-bg-color',
                        'type'      => 'color_rgba',
                        'title'     => __('Background Color Only', 'themeum'),
                        'subtitle'  => __('Select color for site background', 'themeum'),
                        'default'   => array('color' => '#1f1f1f', 'alpha' => '1'),
                        'validate'  => 'colorrgba',
                    ),

                    array(
                        'id'        => 'video-type',
                        'type'      => 'switch',
                        'title'     => __('Choose Your Video Type', 'themeum'),
                        'subtitle'  => __('Enable Youtube/Self Hosted click on that button', 'themeum'),
                        'default'   => true,
                        'on'        => 'YouTube',
                        'off'        => 'Self Hosted Video'
                    ),


                    array(
                        'id'        => 'youtube-video-bg',
                        'type'      => 'text',
                        'title'     => __('Youtube Video Link' , 'themeum'),
                        'subtitle'  => __('add youtube video link here', 'themeum'),
                        'required'  => array('video-type', "=", 1),
                        'placeholder' => 'https://youtube.com/iwqeoiuqwj2'
                    ),

                    array(
                        'id'        => 'own-video-bg',
                        'type'      => 'text',
                        'title'     => __('Self Hosted Video Link' , 'themeum'),
                        'subtitle'  => __('add self video link here', 'themeum'),
                        'required'  => array('video-type', "=", 0),
                        'placeholder' => 'http://demo.themeum.com/video/example.mp4'
                    ),
                    array(
                        'id'        => 'video-sound',
                        'type'      => 'switch',
                        'title'     => __('Enable Video Sound', 'themeum'),
                        'subtitle'  => __('Enable sound for Youtube/Self Hosted video', 'themeum'),
                        'default'   => false,
                        'on'        => 'On',
                        'off'        => 'Off'
                    ),

                    array(
                        'id'        =>'video-fall-bg',
                        'url'       => false,
                        'type'      => 'media', 
                        'title'     => __('Video Fallback Image for Mobile Device', 'themeum'),
                        'subtitle'  => __('Upload image for mobile device background', 'themeum'),
                    ),
                )
            );


            /**********************************
            ********* Styling ***********
            ***********************************/

            $this->sections[] = array(
                'icon' => 'el-icon-brush',
                'icon_class' => 'el-icon-large',
                'title'     => __('Styling', 'themeum'),
                'fields'    => array(

                    array(
                        'id'        => 'preset',
                        'type'      => 'image_select',
                        'compiler'  => true,
                        'title'     => __('Preset Layout', 'themeum'),
                        'subtitle'  => __('select any preset', 'themeum'),
                        'options'   => array(
                            '1' => array('alt' => 'Preset 1',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset1.png'),
                            '2' => array('alt' => 'Preset 2',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset2.png'),
                            '3' => array('alt' => 'Preset 3',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset3.png'),
                            '4' => array('alt' => 'Preset 4',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset4.png'),
                            '5' => array('alt' => 'Preset 5',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset5.png'),
                            '6' => array('alt' => 'Preset 6',       'img' => ReduxFramework::$_url . 'assets/img/presets/preset6.png')
                        ),
                        'default'   => '1'
                    ),

                    array(
                        'id'        => 'custom-preset-en',
                        'type'      => 'switch',
                        'title'     => __('Select Custom Color', 'themeum'),
                        'subtitle' => __('You can use unlimited color', 'themeum'),
                        'default'   => false,
                        
                    ),

                     array(
                        'id'        => 'link-color',
                        'type'      => 'color',
                        'title'     => __('Link Color', 'themeum'),
                        'subtitle'  => __('Pick a link color (default: #EC5538).', 'themeum'),
                        'default'   => '#EC5538',
                        'validate'  => 'color',
                        'transparent'   =>false,
                        'required'  => array('custom-preset-en', "=", 1),
                    ),

                     array(
                        'id'        => 'hover-color',
                        'type'      => 'color',
                        'title'     => __('Hover Color', 'themeum'),
                        'subtitle'  => __('Pick a hover color (default: #DC3515).', 'themeum'),
                        'default'   => '#DC3515',
                        'validate'  => 'color',
                        'transparent'   =>false,
                        'required'  => array('custom-preset-en', "=", 1),
                    ),   

                    array(
                        'id'        => 'content-bg',
                        'type'      => 'color_rgba',
                        'title'     => __('Content Background', 'themeum'),
                        'subtitle'  => __('Content background', 'themeum'),
                        'default'   => array('color' => '#000000', 'alpha' => '.8'),
                        'output'    => array('.box, #sidebar .widget '),
                        'mode'      => 'background',
                        'validate'  => 'colorrgba',
                    ),                                                           

                )
            );




            /**********************************
            ********* Typography ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-font',
                'icon_class' => 'el-icon-large',                
                'title'     => __('Typography', 'themeum'),
                'fields'    => array(

                    array(
                        'id'            => 'body-font',
                        'type'          => 'typography',
                        'title'         => __('Body Font', 'themeum'),
                        'compiler'      => false,  // Use if you want to hook in your own CSS compiler
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => false,    // Select a backup non-google font in addition to a google font
                        'font-style'    => true, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets'       => true, // Only appears if google is true and subsets not set to false
                        //'font-size'     => ture,
                        // 'text-align'    => false,
                        'line-height'   => false,
                        'word-spacing'  => false,  // Defaults to false
                        'letter-spacing'=> false,  // Defaults to false
                        'color'         => true,
                        'preview'       => true, // Disable the previewer
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'output'        =>array('body, p'),
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Select your website body Font', 'themeum'),
                        'default'       => array(
                            'color'         => '#ffffff',
                            'font-weight'    => '300',
                            'font-family'   => 'Dosis',
                            'google'        => true,
                            'font-size'     => '16px'),
                    ), 

                    array(
                        'id'            => 'headings-font',
                        'type'          => 'typography',
                        'title'         => __('Headings Font', 'themeum'),
                        'compiler'      => false,  // Use if you want to hook in your own CSS compiler
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => false,    // Select a backup non-google font in addition to a google font
                        'font-style'    => true, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets'       => true, // Only appears if google is true and subsets not set to false
                        //'font-size'     => ture,
                        // 'text-align'    => false,
                        'line-height'   => false,
                        'font-size'   => false,
                        'word-spacing'  => false,  // Defaults to false
                        'letter-spacing'=> false,  // Defaults to false
                        'color'         => true,
                        'preview'       => true, // Disable the previewer
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'output'        =>array('h1, h2, h3, h4, h5, h6'),
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Select your website headings Font', 'themeum'),
                        'default'       => array(
                            'color'         => '#ffffff',
                            'font-weight'    => '300',
                            'font-family'   => 'Dosis',
                            'google'        => true,
                            ),
                    ), 

                )
            );


            /**********************************
            ********* Blog  ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-edit',
                'icon_class' => 'el-icon-large',                  
                'title'     => __('Blog', 'themeum'),
                'fields'    => array(

                    array(
                        'id'        => 'blog-share-button-en',
                        'type'      => 'switch',
                        'title'     => __('Enable Social Share Button', 'themeum'),
                        'subtitle'  => __('Enable or disable social share button ', 'themeum'),
                        'default'   => true,
                    ),


                    array(
                        'id'        => 'blog-category-en',
                        'type'      => 'switch',
                        'title'     => __('Blog Category', 'themeum'),
                        'subtitle'  => __('Enable or disable blog category ', 'themeum'),
                        'default'   => true,
                    ), 

                    array(
                        'id'        => 'blog-date-en',
                        'type'      => 'switch',
                        'title'     => __('Blog Date', 'themeum'),
                        'subtitle'  => __('Enable or disable blog date ', 'themeum'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'blog-author-en',
                        'type'      => 'switch',
                        'title'     => __('Blog Author', 'themeum'),
                        'subtitle'  => __('Enable or disable blog author ex. Admin', 'themeum'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'blog-comment-en',
                        'type'      => 'switch',
                        'title'     => __('Post Comment', 'themeum'),
                        'subtitle'  => __('Enable or disable post comment', 'themeum'),
                        'default'   => true,
                    ),  


                    array(
                        'id'        => 'blog-edit-en',
                        'type'      => 'switch',
                        'title'     => __('Post Edit', 'themeum'),
                        'subtitle'  => __('Enable or disable post edit', 'themeum'),
                        'default'   => true,
                    ),   


                    array(
                        'id'        => 'blog-tag-en',
                        'type'      => 'switch',
                        'title'     => __('Blog Tag', 'themeum'),
                        'subtitle'  => __('Enable or disable blog tag ', 'themeum'),
                        'default'   => true,
                    ),                                        
                    
                    array(
                        'id'        => 'blog-single-comment-en',
                        'type'      => 'switch',
                        'title'     => __('Single Post Comment', 'themeum'),
                        'subtitle'  => __('Enable or disable single post comment ', 'themeum'),
                        'default'   => true,
                    ),
                )
            );


            /**********************************
            ********* Vocal Plugins  ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-music',
                'icon_class' => 'el-icon-large',                  
                'title'     => __('Vocal Plugins Settings', 'themeum'),
                'fields'    => array(
                    array(
                        'id'        => 'event-social-en',
                        'type'      => 'switch',
                        'title'     => __('Event Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for event single page', 'themeum'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'event-post-per-page',
                        'type'      => 'text',
                        'title'     => __('Post Per Page', 'themeum'),
                        'subtitle'  => __('Post Per Page for archive, category, listing of Album', 'themeum'),
                        'default'   => '12',
                    ),
                    //Performer Single Page Settings
                    array(
                        'id'        => 'performer-type',
                        'type'      => 'select',
                        'title'     => __('Performer Single Page Event Type:', 'themeum'),
                        'options'   => array(
                            'upcomming'     => 'Upcomming Event',
                            'past_event'    => 'Past Event',
                            'all_event'     => 'All Event',
                        ),
                        'default'   => 'performer-type',
                    ),
                    array(
                        'id'        => 'event-show',
                        'type'      => 'switch',
                        'title'     => __('Performer Single Page Event', 'themeum'),
                        'subtitle'  => __('Enable or disable', 'themeum'),
                        'default'   => true
                    ),                    
                    array(
                        'id'        => 'performer-social-en',
                        'type'      => 'switch',
                        'title'     => __('Performer Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for Performer single page', 'themeum'),
                        'default'   => true,
                    ),
                    array(
                        'id' => 'subsection-event-start',
                        'type' => 'section',
                        'title'=> __( 'Album  Post Type Settings', 'themeum' ),
                        'start' => true,
                        'indent' => true
                    ),
                    array(
                        'id'=>'subsection-event-end',
                        'type' => 'section', 
                        'start' => false,
                        'indent' => false 
                    ),
                    array(
                        'id'        => 'album-post-per-page',
                        'type'      => 'text',
                        'title'     => __('Post Per Page', 'themeum'),
                        'subtitle'  => __('Post Per Page for archive, category, listing of Album', 'themeum'),
                        'default'   => '12',
                    ),
                    array(
                        'id'        => 'album-social-en',
                        'type'      => 'switch',
                        'title'     => __('Album Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for album single page', 'themeum'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'disable-related-album',
                        'type'      => 'switch',
                        'title'     => __('Disable Related Album', 'themeum'),
                        'subtitle'  => __('Enable or disable Related Album from Single Page', 'themeum'),
                        'default'   => false,
                    ),
                    array(
                        'id' => 'subsection-gallery-start',
                        'type' => 'section',
                        'title'=> __( 'Gallery  Post Type Settings', 'themeum' ),
                        'start' => true,
                        'indent' => true
                    ),
                    array(
                        'id'=>'subsection-gallery-end',
                        'type' => 'section', 
                        'start' => false,
                        'indent' => false 
                    ),
                    array(
                        'id'        => 'photo-download',
                        'type'      => 'switch',
                        'title'     => __('Photo Download Button', 'themeum'),
                        'subtitle'  => __('Enable or disable Image Gallery Photo Download Button', 'themeum'),
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'gallery-post-per-page',
                        'type'      => 'text',
                        'title'     => __('Post Per Page', 'themeum'),
                        'subtitle'  => __('Post Per Page for archive, category, listing of Gallery', 'themeum'),
                        'default'   => '12',
                    ),
                    array(
                        'id'        => 'gallery-social-en',
                        'type'      => 'switch',
                        'title'     => __('Gallery Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for gallery single page', 'themeum'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'gallery-single-col',
                        'type'      => 'select',
                        'title'     => __('Gallery Single Page Column', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for gallery single page', 'themeum'),
                        'options'  => array(
                            '6' => 'Column 2',
                            '4' => 'Column 3',
                            '3' => 'Column 4'
                        ),
                        'default'  => '4'
                    ),
                    array(
                        'id' => 'subsection-video-start',
                        'type' => 'section',
                        'title'=> __( 'Video Post Type Settings', 'themeum' ),
                        'start' => true,
                        'indent' => true
                    ),
                    array(
                        'id'=>'subsection-video-end',
                        'type' => 'section', 
                        'start' => false,
                        'indent' => false 
                    ),
                    array(
                        'id'        => 'video-post-per-page',
                        'type'      => 'text',
                        'title'     => __('Post Per Page', 'themeum'),
                        'subtitle'  => __('Post Per Page for archive, category, listing of Video', 'themeum'),
                        'default'   => '12',
                    ),
                    array(
                        'id'        => 'video-social-en',
                        'type'      => 'switch',
                        'title'     => __('Video Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share for video single page', 'themeum'),
                        'default'   => true,
                    ),
                    array(
                        'id'        => 'hide-video-cats',
                        'type'      => 'switch',
                        'title'     => __('Hide Categories', 'themeum'),
                        'subtitle'  => __('Hide categories for video single page', 'themeum'),
                        'default'   => false,
                        'on'        => 'Yes',
                        'off'       => 'No'
                    ),
                )
            );


            /**********************************
            ********* Social Link  ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-time',
                'icon_class' => 'el-icon-large',                  
                'title'     => __('Coming Soon', 'themeum'),
                'fields'    => array(

                    array(
                        'id'        => 'comingsoon-en',
                        'type'      => 'switch',
                        'title'     => __('Enable Coming Soon', 'themeum'),
                        'subtitle'  => __('Enable or disable coming soon mode', 'themeum'),
                        'default'   => false,
                    ),

                    array(
                        'id'        => 'comingsoon-date',
                        'type'      => 'date',
                        'title'     => __('Coming Soon date', 'themeum'),
                        'subtitle' => __('Coming Soon Date', 'themeum')
                    ),

                    array(
                        'id'        => 'comingsoon-title',
                        'type'      => 'text',
                        'title'     => __('Title', 'themeum'),
                        'subtitle' => __('Coming Soon Title', 'themeum')
                    ),

                    array(
                        'id'        => 'comingsoon-message-desc',
                        'type'      => 'text',
                        'title'     => __('Description', 'themeum'),
                        'subtitle' => __('Coming Soon Description', 'themeum')
                    ), 

                    array(
                        'id'        => 'csshare-en',
                        'type'      => 'switch',
                        'title'     => __('Coming Soon Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable', 'themeum'),
                        'default'   => true,
                    ),


                    array(
                        'id'        => 'csfacebook',
                        'type'      => 'text',
                        'title'     => __('Facebook URL', 'themeum'),
                        'subtitle' => __('Add facebook url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                      

                    array(
                        'id'        => 'cstwitter',
                        'type'      => 'text',
                        'title'     => __('Twitter URL', 'themeum'),
                        'subtitle' => __('Add twitter url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ), 

                    array(
                        'id'        => 'csgplus',
                        'type'      => 'text',
                        'title'     => __('Google Plus URL', 'themeum'),
                        'subtitle'  => __('Add Google Plus url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                       

                    array(
                        'id'        => 'csyoutube',
                        'type'      => 'text',
                        'title'     => __('Youtube URL', 'themeum'),
                        'subtitle'  => __('Add Youtube url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                       

                    array(
                        'id'        => 'cssoundcloud',
                        'type'      => 'text',
                        'title'     => __('SoundCloud URL', 'themeum'),
                        'subtitle'  => __('Add soundcloud url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                       

                )
            );


            /**********************************
            ********* Social Link  ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-share-alt',
                'icon_class' => 'el-icon-large',                  
                'title'     => __('Socal Link', 'themeum'),
                'fields'    => array(

                    array(
                        'id'        => 'share-en',
                        'type'      => 'switch',
                        'title'     => __('Social Share', 'themeum'),
                        'subtitle'  => __('Enable or disable social share', 'themeum'),
                        'default'   => true,
                    ),


                    array(
                        'id'        => 'facebook',
                        'type'      => 'text',
                        'title'     => __('Facebook URL', 'themeum'),
                        'subtitle'  => __('Add facebook url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                        'default'   => 'https://www.facebook.com/themeum'
                    ),                      

                    array(
                        'id'        => 'twitter',
                        'type'      => 'text',
                        'title'     => __('Twitter URL', 'themeum'),
                        'subtitle' => __('Add twitter url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ), 

                    array(
                        'id'        => 'gplus',
                        'type'      => 'text',
                        'title'     => __('Google Plus URL', 'themeum'),
                        'subtitle'  => __('Add Google Plus url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                       

                    array(
                        'id'        => 'youtube',
                        'type'      => 'text',
                        'title'     => __('Youtube URL', 'themeum'),
                        'subtitle'  => __('Add Youtube url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                        'default'   => '#',
                    ),                       

                    array(
                        'id'        => 'soundcloud',
                        'type'      => 'text',
                        'title'     => __('SoundCloud URL', 'themeum'),
                        'subtitle'  => __('Add soundcloud url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                        'default'   => '#',
                    ),   

                    array(
                        'id'        => 'linkedin',
                        'type'      => 'text',
                        'title'     => __('Linkedin URL', 'themeum'),
                        'subtitle'  => __('Add linkedin url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ), 

                    array(
                        'id'        => 'pinterest',
                        'type'      => 'text',
                        'title'     => __('Pinterest URL', 'themeum'),
                        'subtitle'  => __('Add pinterest url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                        

                    array(
                        'id'        => 'delicious',
                        'type'      => 'text',
                        'title'     => __('Delicious URL', 'themeum'),
                        'subtitle'  => __('Add delicious url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                       

                    array(
                        'id'        => 'tumblr',
                        'type'      => 'text',
                        'title'     => __('Tumblr URL', 'themeum'),
                        'subtitle'  => __('Add tumblr url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),                      

                    array(
                        'id'        => 'stumbleupon',
                        'type'      => 'text',
                        'title'     => __('Stumbleupon URL', 'themeum'),
                        'subtitle'  => __('Add stumbleupon url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),

                    array(
                        'id'        => 'instagram',
                        'type'      => 'text',
                        'title'     => __('Instagram URL', 'themeum'),
                        'subtitle'  => __('Add instagram url', 'themeum'),
                        'required'  => array('share-en', "=", 1),
                    ),  

                )
            );


            /**********************************
            ********* Footer ***********
            ***********************************/

            $this->sections[] = array(
                'icon'      => 'el-icon-bookmark',
                'icon_class' => 'el-icon-large', 
                'title'     => __('Footer', 'themeum'),
                'fields'    => array(

                    array(
                        'id'        => 'footer-text-color',
                        'type'      => 'color',
                        'title'     => __('Footer Text Color', 'themeum'),
                        'subtitle'  => __('Pick Footer Text color (default: #fff)', 'themeum'),
                        'default'   => '#fff',
                        'validate'  => 'color',
                        'transparent'   =>false,
                    ), 

                    array(
                        'id'        => 'footer-padding-top',
                        'type'      => 'text',
                        'title'     => __('Footer Top Padding', 'themeum'),
                        'subtitle' => __('Enter custom Footer top padding', 'themeum'),
                        'default'   => '',

                    ),  

                    array(
                        'id'        => 'footer-padding-bottom',
                        'type'      => 'text',
                        'title'     => __('Footer Bottom Padding', 'themeum'),
                        'subtitle' => __('Enter custom Footer bottom padding', 'themeum'),
                        'default'   => '',

                    ),                   

                    array(
                        'id'        => 'copyright-en',
                        'type'      => 'switch',
                        'title'     => __('Copyright', 'themeum'),
                        'subtitle'  => __('Enable or disable copyright', 'themeum'),
                        'default'   => true,
                    ),                    

                    array(
                        'id'        => 'copyright-text',
                        'type'      => 'editor',
                        'title'     => __('Copyright Text', 'themeum'),
                        'subtitle'  => __('Add copyright text', 'themeum'),
                        'default'   => __('Copyright &copy; 2014 Vocal. <br/> Designed by <a href="http://wwww.themeum.com/" target="_blank" >themeum</a>', 'themeum'),
                        'required'  => array('copyright-en', "=", 1),
                        
                    ),  
                )
            );


            /**********************************
            ********* Import / Export ***********
            ***********************************/

            $this->sections[] = array(
                'title'     => __('Import / Export', 'themeum'),
                'desc'      => __('Import and Export your Theme Options settings from file, text or URL.', 'themeum'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => __('Import Export', 'themeum'),
                        'subtitle'      => __('Save and restore your Redux options', 'themeum'),
                        'full_width'    => false,
                    ),
                ),
            );
        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => __('Theme Information 1', 'redux-framework-demo'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => __('Theme Information 2', 'redux-framework-demo'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo');
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'          => 'themeum_options',            // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'      => $theme->get('Name'),     // Name that appears at the top of your panel
                'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
                'menu_type'         => 'menu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
                'menu_title'        => __('Vocal Theme Options', 'themeum'),
                'page_title'        => __('Vocal Theme Options', 'themeum'),
                
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '', // Must be defined to add google fonts to the typography module
                
                'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
                'admin_bar'         => true,                    // Show the panel pages on the admin bar
                'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
                'dev_mode'          => false,                    // Show the time the page took to load, etc
                'customizer'        => true,                    // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
                'menu_icon'         => '',                      // Specify a custom URL to an icon
                'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
                'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
                'page_slug'         => '_options',              // Page slug used to denote the panel
                'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
                'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
                'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,                   // Shows the Import/Export panel when not used as a field.
                
                // CAREFUL -> These options are for advanced use only
                'transient_time'    => 60 * MINUTE_IN_SECONDS,
                'output'            => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
                
                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'           => false, // REMOVE

                // HINTS
                'hints' => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'         => 'light',
                        'shadow'        => true,
                        'rounded'       => false,
                        'style'         => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show'          => array(
                            'effect'        => 'slide',
                            'duration'      => '500',
                            'event'         => 'mouseover',
                        ),
                        'hide'      => array(
                            'effect'    => 'slide',
                            'duration'  => '500',
                            'event'     => 'click mouseleave',
                        ),
                    ),
                )
            );
         }

    }
    
    global $reduxConfig;
    $reduxConfig = new Redux_Framework_sample_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')):
    function redux_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')):
    function redux_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
