<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Admin functions for the Event post type
 *
 * @author 		Themeum
 * @category 	Admin
 * @package 	Vocal
 * @version     1.0
 *-------------------------------------------------------------*/

/**
 * Register post type event
 *
 * @return void
 */

function themeum_post_type_album()
{
	$labels = array( 
		'name'                	=> _x( 'Albums', 'Albums', 'vocal-event' ),
		'singular_name'       	=> _x( 'Album', 'Album', 'vocal-event' ),
		'menu_name'           	=> __( 'Albums', 'vocal-event' ),
		'parent_item_colon'   	=> __( 'Parent Album:', 'vocal-event' ),
		'all_items'           	=> __( 'All Albums', 'vocal-event' ),
		'view_item'           	=> __( 'View Album', 'vocal-event' ),
		'add_new_item'        	=> __( 'Add New Album', 'vocal-event' ),
		'add_new'             	=> __( 'New Album', 'vocal-event' ),
		'edit_item'           	=> __( 'Edit Album', 'vocal-event' ),
		'update_item'         	=> __( 'Update Album', 'vocal-event' ),
		'search_items'        	=> __( 'Search Album', 'vocal-event' ),
		'not_found'           	=> __( 'No article found', 'vocal-event' ),
		'not_found_in_trash'  	=> __( 'No article found in Trash', 'vocal-event' )
		);

	$args = array(  
		'labels'             	=> $labels,
		'public'             	=> true,
		'publicly_queryable' 	=> true,
		'show_in_menu'       	=> true,
		'show_in_admin_bar'   	=> true,
		'can_export'          	=> true,
		'has_archive'        	=> true,
		'hierarchical'       	=> false,
		'menu_position'      	=> null,
		'menu_icon'				=> '',
		'supports'           	=> array( 'title','editor','thumbnail','comments'), 
		'taxonomies' 			=> array('post_tag')
		);

	register_post_type('album', $args);

}

add_action('init','themeum_post_type_album');


/**
 * View Message When Updated Project
 *
 * @param array $messages Existing post update messages.
 * @return array
 */

function themeum_update_message_album( $messages )
{
	global $post, $post_ID;

	$message['event'] = array(
		0 => '',
		1 => sprintf( __('Album updated. <a href="%s">View Album</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'vocal-event' ),
		3 => __('Custom field deleted.', 'vocal-event' ),
		4 => __('Album updated.', 'vocal-event' ),
		5 => isset($_GET['revision']) ? sprintf( __('Album restored to revision from %s', 'vocal-event' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Album published. <a href="%s">View Album</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		7 => __('Album saved.', 'vocal-event' ),
		8 => sprintf( __('Album submitted. <a target="_blank" href="%s">Preview Album</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Album scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Album</a>', 'vocal-event' ), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Album draft updated. <a target="_blank" href="%s">Preview Album</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		);

return $message;
}

add_filter( 'post_updated_messages', 'themeum_update_message_album' );


/**
 * Register Gallery Category Taxonomies
 *
 * @return void
 */

function themeum_register_album_cat_taxonomy()
{
	$labels = array(	
		'name'              	=> _x( 'Album Categories', 'taxonomy general name', 'vocal-event' ),
		'singular_name'     	=> _x( 'Album Category', 'taxonomy singular name', 'vocal-event' ),
		'search_items'      	=> __( 'Search Category', 'vocal-event' ),
		'all_items'         	=> __( 'All Category', 'vocal-event' ),
		'parent_item'       	=> __( 'Parent Category', 'vocal-event' ),
		'parent_item_colon' 	=> __( 'Parent Category:', 'vocal-event' ),
		'edit_item'         	=> __( 'Edit Category', 'vocal-event' ),
		'update_item'       	=> __( 'Update Category', 'vocal-event' ),
		'add_new_item'      	=> __( 'Add New Category', 'vocal-event' ),
		'new_item_name'     	=> __( 'New Category Name', 'vocal-event' ),
		'menu_name'         	=> __( 'Albums Category', 'vocal-event' )
		);

	$args = array(	'hierarchical'      	=> true,
		'labels'            	=> $labels,
		'show_ui'           	=> true,
		'show_admin_column' 	=> true,
		'query_var'         	=> true
		);

	register_taxonomy('album_cat',array( 'album' ),$args);
}

add_action('init','themeum_register_album_cat_taxonomy');