<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Admin functions for the Event post type
 *
 * @author 		Themeum
 * @category 	Admin
 * @package 	Vocal
 * @version     1.0
 *-------------------------------------------------------------*/

/**
 * Register post type event
 *
 * @return void
 */

function themeum_post_type_event()
{
	$labels = array( 
		'name'                	=> _x( 'Events', 'Events', 'vocal-event' ),
		'singular_name'       	=> _x( 'Event', 'Event', 'vocal-event' ),
		'menu_name'           	=> __( 'Events', 'vocal-event' ),
		'parent_item_colon'   	=> __( 'Parent Event:', 'vocal-event' ),
		'all_items'           	=> __( 'All Events', 'vocal-event' ),
		'view_item'           	=> __( 'View Event', 'vocal-event' ),
		'add_new_item'        	=> __( 'Add New Event', 'vocal-event' ),
		'add_new'             	=> __( 'New Event', 'vocal-event' ),
		'edit_item'           	=> __( 'Edit Event', 'vocal-event' ),
		'update_item'         	=> __( 'Update Event', 'vocal-event' ),
		'search_items'        	=> __( 'Search Event', 'vocal-event' ),
		'not_found'           	=> __( 'No article found', 'vocal-event' ),
		'not_found_in_trash'  	=> __( 'No article found in Trash', 'vocal-event' )
		);

	$args = array(  
		'labels'             	=> $labels,
		'public'             	=> true,
		'publicly_queryable' 	=> true,
		'show_in_menu'       	=> true,
		'show_in_admin_bar'   	=> true,
		'can_export'          	=> true,
		'has_archive'        	=> true,
		'hierarchical'       	=> false,
		'menu_position'      	=> null,
		'menu_icon'				=> '',
		'supports'           	=> array( 'title','editor','thumbnail','comments')
		);

	register_post_type('event',$args);

}

add_action('init','themeum_post_type_event');


/**
 * View Message When Updated Project
 *
 * @param array $messages Existing post update messages.
 * @return array
 */

function themeum_update_message_event( $messages )
{
	global $post, $post_ID;

	$message['event'] = array(
		0 => '',
		1 => sprintf( __('Event updated. <a href="%s">View Event</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'vocal-event' ),
		3 => __('Custom field deleted.', 'vocal-event' ),
		4 => __('Event updated.', 'vocal-event' ),
		5 => isset($_GET['revision']) ? sprintf( __('Event restored to revision from %s', 'vocal-event' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Event published. <a href="%s">View Event</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		7 => __('Event saved.', 'vocal-event' ),
		8 => sprintf( __('Event submitted. <a target="_blank" href="%s">Preview Event</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Event scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Event</a>', 'vocal-event' ), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Event draft updated. <a target="_blank" href="%s">Preview Event</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		);

return $message;
}

add_filter( 'post_updated_messages', 'themeum_update_message_event' );


/**
 * Register Event Category Taxonomies
 *
 * @return void
 */

function themeum_register_event_cat_taxonomy()
{
	$labels = array(
		'name'              	=> _x( 'Event Categories', 'taxonomy general name', 'vocal-event' ),
		'singular_name'     	=> _x( 'Event Category', 'taxonomy singular name', 'vocal-event' ),
		'search_items'      	=> __( 'Search Event Category', 'vocal-event' ),
		'all_items'         	=> __( 'All Event Category', 'vocal-event' ),
		'parent_item'       	=> __( 'Event Parent Category', 'vocal-event' ),
		'parent_item_colon' 	=> __( 'Event Parent Category:', 'vocal-event' ),
		'edit_item'         	=> __( 'Edit Event Category', 'vocal-event' ),
		'update_item'       	=> __( 'Update Event Category', 'vocal-event' ),
		'add_new_item'      	=> __( 'Add New Event Category', 'vocal-event' ),
		'new_item_name'     	=> __( 'New Event Category Name', 'vocal-event' ),
		'menu_name'         	=> __( 'Event Category', 'vocal-event' )
		);

	$args = array(	'hierarchical'      	=> true,
		'labels'            	=> $labels,
		'show_ui'           	=> true,
		'show_admin_column' 	=> true,
		'query_var'         	=> true
		);

	register_taxonomy('event_cat',array( 'event' ),$args);
}

add_action('init','themeum_register_event_cat_taxonomy');




