<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Admin functions for the Performers Post Type
 *
 * @author 		Themeum
 * @category 	Admin
 * @package 	Vocal
 * @version     1.0
 *
 *-------------------------------------------------------------*/

/**
 * Register Post Type Performer
 *
 * @return void
 */

function themeum_post_type_performer()
{
	$labels = array( 
		'name'                	=> _x( 'Performers', 'Performers', 'vocal-event' ),
		'singular_name'       	=> _x( 'Performer', 'Performer', 'vocal-event' ),
		'menu_name'           	=> __( 'Performers', 'vocal-event' ),
		'parent_item_colon'   	=> __( 'Parent Performer:', 'vocal-event' ),
		'all_items'           	=> __( 'All Performer', 'vocal-event' ),
		'view_item'           	=> __( 'View Performer', 'vocal-event' ),
		'add_new_item'        	=> __( 'Add New Performer', 'vocal-event' ),
		'add_new'             	=> __( 'New Performer', 'vocal-event' ),
		'edit_item'           	=> __( 'Edit Performer', 'vocal-event' ),
		'update_item'         	=> __( 'Update Performer', 'vocal-event' ),
		'search_items'        	=> __( 'Search Performer', 'vocal-event' ),
		'not_found'           	=> __( 'No article found', 'vocal-event' ),
		'not_found_in_trash'  	=> __( 'No article found in Trash', 'vocal-event' )
		);

	$args = array(  
		'labels'             	=> $labels,
		'public'             	=> true,
		'publicly_queryable' 	=> true,
		'show_in_menu'       	=> true,
		'show_in_admin_bar'   	=> true,
		'can_export'          	=> true,
		'has_archive'        	=> true,
		'hierarchical'       	=> false,
		'menu_position'      	=> null,
		'menu_icon'				=> '',
		'supports'           	=> array( 'title','editor','thumbnail')
		);

	register_post_type('performer',$args);

}

add_action('init','themeum_post_type_performer');


/**
 * View Message When Updated Project
 *
 * @param array $messages Existing post update messages.
 * @return array
 */

function themeum_update_message_performer( $messages )
{
	global $post, $post_ID;

	$message['performer'] = array(
		0 => '',
		1 => sprintf( __('Performer updated. <a href="%s">View Performer</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'vocal-event' ),
		3 => __('Custom field deleted.', 'vocal-event' ),
		4 => __('Performer updated.', 'vocal-event' ),
		5 => isset($_GET['revision']) ? sprintf( __('Performer restored to revision from %s', 'vocal-event' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Performer published. <a href="%s">View Performer</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		7 => __('Performer saved.', 'vocal-event' ),
		8 => sprintf( __('Performer submitted. <a target="_blank" href="%s">Preview Performer</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Performer scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Performer</a>', 'vocal-event' ), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Performer draft updated. <a target="_blank" href="%s">Preview Performer</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		);

return $message;
}

add_filter( 'post_updated_messages', 'themeum_update_message_performer' );


/**
 * Register Event Category Taxonomies
 *
 * @return void
 */

function themeum_register_performer_cat_taxonomy()
{
	$labels = array(
		'name'              	=> _x( 'Performer Categories', 'taxonomy general name', 'vocal-event' ),
		'singular_name'     	=> _x( 'Performer Category', 'taxonomy singular name', 'vocal-event' ),
		'search_items'      	=> __( 'Search Category', 'vocal-event' ),
		'all_items'         	=> __( 'All Category', 'vocal-event' ),
		'parent_item'       	=> __( 'Parent Category', 'vocal-event' ),
		'parent_item_colon' 	=> __( 'Parent Category:', 'vocal-event' ),
		'edit_item'         	=> __( 'Edit Category', 'vocal-event' ),
		'update_item'       	=> __( 'Update Category', 'vocal-event' ),
		'add_new_item'      	=> __( 'Add New Category', 'vocal-event' ),
		'new_item_name'     	=> __( 'New Category Name', 'vocal-event' ),
		'menu_name'         	=> __( 'Performer Category', 'vocal-event' )
		);

	$args = array(	'hierarchical'      	=> true,
		'labels'            	=> $labels,
		'show_ui'           	=> true,
		'show_admin_column' 	=> true,
		'query_var'         	=> true
		);

	register_taxonomy('performer_cat',array( 'performer' ),$args);
}

add_action('init','themeum_register_performer_cat_taxonomy');



/*--------------------------------------------------------------
 *					Add Submenu
 *-------------------------------------------------------------*/

function performer_posts_sort()
{
    add_submenu_page('edit.php?post_type=performer', 'Sort Terformer', 'Sort', 'edit_posts', basename(__FILE__), 'performer_posts_sort_callback');
}

add_action('admin_menu' , 'performer_posts_sort');


function performer_posts_sort_callback()
{
	$members = new WP_Query('post_type=performer&posts_per_page=-1&orderby=menu_order&order=ASC');
?>
	<div class="wrap">
		<h3><?php  _e('Sort Performers'); ?><img src="<?php echo home_url(); ?>/wp-admin/images/loading.gif" id="loading-animation" /></h3>
		<ul id="slide-list">
			<?php if($members->have_posts()): ?>
				<?php while ( $members->have_posts() ){ $members->the_post(); ?>
					<li id="<?php the_id(); ?>"><?php the_title(); ?></li>			
				<?php } ?>
			<?php else: ?>
				<li>There is no Slide Created</li>		
			<?php endif; ?>
		</ul>
	</div>
<?php
}


/*--------------------------------------------------------------
 *				Add Sub-Menu Admin Style
 *-------------------------------------------------------------*/

function performer_posts_sort_styles()
{
	$screen = get_current_screen();
	
	if($screen->post_type == 'performer')
	{
		wp_enqueue_style( 'sort-stylesheet', plugins_url( '../assets/css/sort-stylesheet.css' , __FILE__ ), array(), false, false );
		wp_enqueue_script('jquery-ui-sortable');
		wp_enqueue_script( 'sort-script', plugins_url( '../assets/js/sort-script.js' , __FILE__ ), array(), false, true );
	}
}

add_action( 'admin_print_styles', 'performer_posts_sort_styles' );


/*--------------------------------------------------------------
 *				Ajax Call-back
 *-------------------------------------------------------------*/

function performer_posts_sort_order()
{
	global $wpdb; // WordPress database class

	$order = explode(',', $_POST['order']);
	$counter = 0;
	
	foreach ($order as $slide_id) {
		$wpdb->update($wpdb->posts, array( 'menu_order' => $counter ), array( 'ID' => $slide_id) );
		$counter++;
	}
	die(1);
}

add_action('wp_ajax_performer_sort', 'performer_posts_sort_order');